# SearchSource: GoogleScholar

Note: This document is currently under development. It will contain the following elements.

- description
- coverage (disciplines, types of work)
- supported (details): run_search (including updates), load,  prep (including get_masterdata)

[GoogleScholar](https://scholar.google.de/)
[Publish or Perish](https://harzing.com/resources/publish-or-perish) supports the retrieval of data from GoogleScholar.

## Add the search source

Download search results and store in `data/search/` directory. No API-access available.

## Links
